pub struct MarketDataService;Implementations
Sourceimpl MarketDataService
impl MarketDataService
Sourcepub fn apply_price(
&self,
store: &mut PriceStore,
instrument: Instrument,
price: f64,
)
pub fn apply_price( &self, store: &mut PriceStore, instrument: Instrument, price: f64, )
Updates the latest known execution price for an instrument.
Example:
- incoming BTCUSDT tick at
50000.0 - stored as the current execution price context for BTCUSDT
pub fn refresh_price<E: ExchangeFacade<Error = ExchangeError>>( &self, exchange: &E, store: &mut PriceStore, instrument: Instrument, market: Market, ) -> Result<f64, ExchangeError>
pub fn current_price( &self, store: &impl PriceSource, instrument: &Instrument, ) -> Option<f64>